@@ -37,7 +37,7 @@ function(data1, data2, by=NULL, quiet=getOption("quiet"), ...) {
       cat("\n"); stop(call.=FALSE, "\n","------\n",
         "To do a vertical merge, both data sets must have the same variables.\n\n")
     }
-    mylabels <- attr(data1, which="variable.labels") # save variable labels
+    l <- attr(data1, which="variable.labels") # save variable labels
     myunits <- attr(data1, which="variable.units") # save variable units
     type <- "vertical"
     data <- rbind(data1, data2)
@@ -45,12 +45,12 @@ function(data1, data2, by=NULL, quiet=getOption("quiet"), ...) {
 
   else {
     type <- "horizontal"
-    mylabels1 <- attr(data1, which="variable.labels") # save variable labels
-    mylabels2 <- attr(data2, which="variable.labels") # save variable labels
+    l1 <- attr(data1, which="variable.labels") # save variable labels
+    l2 <- attr(data2, which="variable.labels") # save variable labels
     myunits1 <- attr(data1, which="variable.units") # save variable units
     myunits2 <- attr(data2, which="variable.units") # save variable units
     data <- merge(data1, data2, by=by, ...)
-    mylabels <- c(mylabels1, mylabels2)
+    l <- c(l1, l2)
     myunits <- c(myunits1, myunits2)
   }
 
@@ -68,7 +68,7 @@ function(data1, data2, by=NULL, quiet=getOption("quiet"), ...) {
   }
 
   # restore any variable labels, units
-  if (!is.null(mylabels)) attr(data, which="variable.labels") <- mylabels
+  if (!is.null(l)) attr(data, which="variable.labels") <- l
   if (!is.null(myunits)) attr(data, which="variable.units") <- myunits
 
   return(data)
